[![](https://img.shields.io/pypi/v/pytorch_probing?style=for-the-badge)](https://pypi.org/project/pytorch_probing) [![](https://img.shields.io/pypi/l/pytorch_probing?style=for-the-badge)](https://github.com/H-IAAC/pytorch-probing/blob/main/LICENSE) [![](https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white)](https://github.com/H-IAAC/pytorch-probing) [![](https://img.shields.io/badge/-Documentation-fe9c22?style=for-the-badge&link=https%3A%2F%2Fh-iaac.github.io%2Fpytorch-probing%2F)](https://h-iaac.github.io/pytorch-probing)

# PyTorch Probing

Python module for creating and using probes with PyTorch modules. 

This project was developed as part of the Cognitive Architectures research line from 
the Hub for Artificial Intelligence and Cognitive Architectures (H.IAAC) of the State University of Campinas (UNICAMP).
See more projects from the group [here](https://github.com/brgsil/RepoOrganizer).

[![](https://img.shields.io/badge/-H.IAAC-eb901a?style=for-the-badge&labelColor=black)](https://hiaac.unicamp.br/)
[![](https://img.shields.io/badge/-Arq.Cog-black?style=for-the-badge&labelColor=white&logo=data:image/svg%2bxml;base64, )](https://github.com/brgsil/RepoOrganizer)

## Repository Structure

- src: pytorch_probing source code
- docs: documentation files
- examples: examples of usage (see the [documentation](https://h-iaac.github.io/pytorch-probing/))
- test: test codes

## Installation / Usage

### Installation

- Installing using pip:

    ```bash
    pip install --upgrade pip
    pip install pytorch_probing
    ```

- For installing from the repository:

    ```bash
    git clone https://github.com/H-IAAC/pytorch_probing
    cd pytorch_probing
    pip install --upgrade pip
    pip install .
    ```

### Usage

See the [documentation](https://h-iaac.github.io/pytorch-probing/) for usage and [examples](https://h-iaac.github.io/pytorch-probing/_build/html/Examples.html).

## Citation

> Quando existente, fornecer o Bibtex para citação do(s) artigo(s) publicados referentes ao
> desenvolvimento desse projeto.

TODO Subir no Zenodo

## Authors
  
- (2024-) [EltonCN](https://github.com/EltonCN) : M. Eng. student, FEEC-Unicamp
  
## Acknowledgements

This project is part of the Hub for Artificial Intelligence and Cognitive Architectures
(H.IAAC- Hub de Inteligência Artificial e Arquiteturas Cognitivas). We acknowledge the 
support of PPI-Softex/MCTI by grant 01245.013778/2020-21 through the Brazilian Federal Government.

## Licence

```
Copyright 2024 H.IAAC

Licensed under the GNU LESSER GENERAL PUBLIC LICENSE, Version 3 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.gnu.org/licenses/lgpl-3.0.html

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
